#
# spec file for package python-pecan
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-pecan
Version:        1.0.2
Release:        3.3
Summary:        A WSGI object-dispatching web framework, designed to be lean and fast
License:        BSD-3-Clause
Group:          Development/Languages/Python
Url:            http://github.com/dreamhost/pecan
Source:         https://pypi.python.org/packages/source/p/pecan/pecan-%{version}.tar.gz
BuildRequires:  python-devel
BuildRequires:  python-setuptools
# Test requirements:
%if 0%{?suse_version} >= 1230 && 0%{?suse_version} != 1315
BuildRequires:  python-Genshi
BuildRequires:  python-Jinja2
BuildRequires:  python-Kajiki
BuildRequires:  python-Mako >= 0.4.0
BuildRequires:  python-SQLAlchemy
BuildRequires:  python-WebTest >= 1.3.1
BuildRequires:  python-gunicorn
BuildRequires:  python-logutils
BuildRequires:  python-mock
BuildRequires:  python-singledispatch
BuildRequires:  python-virtualenv
%endif
BuildRequires:  python-six
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
Requires:       python-ordereddict
%endif
Requires:       python-Mako >= 0.4.0
Requires:       python-WebOb >= 1.2dev
Requires:       python-WebTest >= 1.3.1
Requires:       python-logutils >= 0.3
Requires:       python-singledispatch
Requires:       python-six
%if 0%{?suse_version}
Suggests:       python-Jinja2
Suggests:       python-Genshi
Suggests:       python-gunicorn
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif

%description
A WSGI object-dispatching web framework, designed to be lean and fast with few dependencies.

%prep
%setup -q -n pecan-%{version}
# Let's not depend on Kajiki, a Genshi clone. Genshi should be enough:
sed -i "/'Kajiki',/d" setup.py

%build
python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}

%if 0%{?suse_version} >= 1230 &&  0%{?suse_version} != 1315
%check
python setup.py test
%endif

%files
%defattr(-,root,root,-)
%doc LICENSE README.rst
%{_bindir}/pecan
%{_bindir}/gunicorn_pecan
%{python_sitelib}/*

%changelog
* Sat Aug 22 2015 tbechtold@suse.com
- update to 1.0.2:
  * Version increment.
  * Add a thread lock to `pecan serve --reload` to avoid multiple restarts
  * Fix an argspec detection edge case in `pecan.util.getargspec`
  * Version increment.
  * Fix a subtle bug in pecan.configuration.Config attribute assignment
  * Fix a bug in extension-based content-type guessing with a trailing slash.
  * Mark stable OpenStack branches as non-voting; their tests are often unstable
  * Version increment.
  * Update bug reporting verbiage.
  * core: make status code mandatory in abort
  * Move pecan off of stackforge and back to github.com/pecan and TravisCI.
  * Fix a bug in the way `default_renderer` is applied.
  * Allow all RFC3986-specified characters in explicit path segments.
  * Replace pecan's homegrown interactive debugging middleware with backlash
  * Fix broken wsme-stable tests as of the latest 0.7.0 release.
  * Allowing tracebacks to be surfaced through abort
* Fri Jul 24 2015 seife+obs@b1-systems.com
- fix non-suse build by conditionalizing Suggests: tags
* Mon Jun 22 2015 tbechtold@suse.com
- update to 0.9.0:
  * Require orderddict for Python 2.6 support.
  * Version increment.
  * Add tox environments to gate pecan against openstack/gnocchi
  * Add tox environments to gate pecan against openstack/magnum
  * Gate against latest stable projects.
  * Properly raise HTTP 405 (and specify Allow headers) for RestController
  * Update the `rest-api` scaffold to use generic controllers, *not* RestController Closes-Bug #1413038
  * Allow users to specify custom path segments for routing.
  * Fix broken wsme-stable tests.
  * Replace ci.o.o links with docs.o.o/infra
  * Fix unquoting of positional args with plus sign
  * Add more emphasis to the need for debug=False in deployment documentation.
  * Properly handle Python3 Unicode path segments in pecan routing.
  * make_app() now uses the debugger param in DebugMiddleware()
  * Drop support for Python 3.2.
  * Prevent @expose(generic=True) on special methods (_route, _lookup, _default).
  * core: do not assume controller is a method
  * Fix broken wsme-stable job and pep8 failures.
  * Document how to serve static files (with an iterable, not in-memory).
  * Default the `pecan` log level to DEBUG for development.
- Add python-ordereddict Requires for SLE11SP3
* Tue Feb 24 2015 tbechtold@suse.com
- update to 0.8.3
  * Properly* detect Python < 3.3.
  * Fix py32 support; importlib.machinery.SourceFileLoader doesn't exist until
    py33
  * Version increment.
  * Change pecan to more gracefully handle a few odd request encoding edge
    cases.
  * Document pecan.request.context
  * Improve ImportError verbosity for configuration files.
  * core: optimize renderer computing
  * middleware.static: remove useless stored variable
  * Version increment.
  * Don't clone pecan-dependent projects from cgit.
  * Allows multiple parameters to be converted to list
  * tox: pass posargs to test command
  * Corrects ouptut -> output in docs/source/hooks.rst
  * Add documentation for generic REST controllers.
  * Version increment.
  * Improve detection of infinite recursion for PecanHook and pypy.
  * Fix broken wsme-stable tests and remove some deprecated pip flags.
  * Fix typo in description
  * Only define remainder when not empty
  * Fixes expose of staticmethod
  * Version increment.
  * Resolve a bug that mixes up argument order for generic functions.
  * Fix a routing bug for generic subcontrollers.
  * Remove `assert` for flow control; it can be optimized away with `python -O`.
  * For HTTP POSTs, map JSON request bodies to controller keyword arguments.
  * Improve argspec detection and leniency for wrapped controllers.
  * When path arguments are incorrect for RestController, return HTTP 404, not
    400.
  * When detecting non-content for HTTP 204, properly catch UnicodeDecodeError.
  * Fix a bug in generic function handling when context locals are disabled.
  * Stop using distribute for Python 3 tests.
  * Revert "Import run_cross_tests.sh from oslo-incubator"
  * Add docs environment to tox.ini
* Mon Nov 10 2014 dmueller@suse.com
- skip tests on SLE_12 (the depending packages are not there)
* Tue Sep 23 2014 dmueller@suse.com
- update to 0.7.0:
  * Fixed an edge case in RestController routing which should have
  returned an HTTP 400 but was instead raising an exception
  (and thus, HTTP 500).
  * Fixed an incorrect root logger configuration for
  quickstarted pecan projects.
  * Added pecan.state.arguments, a new feature for inspecting
  controller call arguments.
  * Fixed an infinite recursion error in PecanHook application.
  Subclassing both rest.RestController and hooks.HookController
  resulted in an infinite recursion error in hook application
  (which prevented applications from starting).
  * Pecan’s tests are now included in its source distribution.
- remove-logutils.diff: drop, logutils is needed now
- reenable testsuite run during build again
* Wed Aug 20 2014 tbechtold@suse.com
- Disable testsuite run during build. Upstream tarball doesn't contain
  all needed files to run the testsuite.
* Thu Jul 24 2014 dmueller@suse.com
- update to 0.6.1:
  * Fixed a bug which causes pecan to mistakenly return HTTP 204 for non-empty response bodies.
  * Added support for disabling the pecan.request and pecan.response threadlocals at the WSGI
  application level in favor of explicit reference passing. For more information, see
  Context/Thread-Locals vs. Explicit Argument Passing.
  * Added better support for hook composition via subclassing and mixins. For more
  information, see Attaching Hooks.
  * Added support for specifying custom request and response implementations at the WSGI
  application level for people who want to extend the functionality provided by the base
  classes in webob.
  * Pecan controllers may now return an explicit webob.Response instance to short-circuit
  Pecan’s template rendering and serialization.
  * For generic methods that return HTTP 405, pecan now generates an Allow header to
  communicate acceptable methods to the client.
  * Fixed a bug in adherence to RFC2616: if an exposed method returns no response
  body (or namespace), pecan will now enforce an HTTP 204 response (instead of HTTP 200).
  * Fixed a bug in adherence to RFC2616: when pecan responds with HTTP 204 or HTTP 304,
  the Content-Type header is automatically stripped (because these types of HTTP
  responses do not contain body content).
  * Fixed a bug: now when clients request JSON via an Accept header, webob HTTP
  exceptions are serialized as JSON, not their native HTML representation.
  * Fixed a bug that broke applications which specified default_renderer = json.
  * This release adds formal support for pypy.
  * Added colored request logging to the pecan serve command.
  * Added a scaffold for easily generating a basic REST API.
  * Added the ability to pass arbitrary keyword arguments to pecan.testing.load_test_app.
  * Fixed a recursion-related bug in the error document middleware.
  * Fixed a bug in the gunicorn_pecan command that caused threading.local data to
  leak between eventlet/gevent green threads.
  * Improved documentation through fixes and narrative tutorials for sample pecan applications.
- add remove-logutils.diff: Remove dependency on logutils for newer distros,
  its part of main python now
* Thu Feb 20 2014 dmueller@suse.com
- update to 0.4.5:
  * Fixed a trailing slash bug for `RestController`s that have a `_lookup` method.
  * Cleaned up the WSGI app reference from the threadlocal state on every request
  (to avoid potential memory leaks, especially when testing).
  * Improved pecan documentation and correctd intersphinx references.
  * pecan supports Python 3.4.
* Fri Jan 10 2014 dmueller@suse.com
- update to 0.4.4:
  * Removed memoization of certain controller attributes, which can lead to
  a memory leak in dynamic controller lookups.
  * Fixed several bugs for RestController.
  * Fixed a bug in security handling for generic controllers.
  * Resolved a bug in `_default` handlers used in `RestController`.
  * Persist `pecan.request.context` across internal redirects.
- reenable make check
* Tue Dec 10 2013 dmueller@suse.com
- fix requires after the version update to 0.4.2, it was even
  documented in the .changes file:
  * Replaced the ``simplegeneric`` dependency with the new
  ``functools.singledispatch`` function in preparation for  Python 3.4 support.
* Thu Dec  5 2013 p.drouand@gmail.com
- Update to version 0.4.2
  * Remove a routing optimization that breaks the WSME pecan plugin.
- Changes from 0.4.1
  * Moved the project to `StackForge infrastructure
    <http://ci.openstack.org/stackforge.html>`_, including Gerrit
    code review, Jenkins continuous integration, and GitHub mirroring.
  * Added a pecan plugin for the popular `uwsgi server
    <http://uwsgi-docs.readthedocs.org>`_.
  * Replaced the ``simplegeneric`` dependency with the new
    ``functools.singledispatch`` function in preparation for  Python 3.4 support.
  * Optimized pecan's core dispatch routing for notably faster response times.
* Thu Nov 28 2013 dmueller@suse.com
- package LICENSE and README.rst
* Wed Sep 18 2013 dmueller@suse.com
- require python-logutils on Python < 2.7
* Tue Aug 13 2013 dmueller@suse.com
- update to 0.3.2:
  * Made some changes to simplify how ``pecan.conf.app`` is passed to new apps.
  * Fixed a routing bug for certain ``_lookup`` controller configurations.
  * Improved documentation for handling file uploads.
  * Deprecated the ``pecan.conf.requestviewer`` configuration option.
* Tue Jun 25 2013 dmueller@suse.com
- Update to version 0.3.0:
  + New upstream release
* Fri Feb 22 2013 saschpe@suse.de
- Update to version 0.2.1:
  + Upstream provides no changelog
* Thu Jan 17 2013 saschpe@suse.de
- Initial version
